@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: extension.c,v 1.3 2005/01/13 16:15:48 chpe Exp $
+ *  $Id: extension.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -32,7 +32,7 @@ G_MODULE_EXPORT GType register_module (GTypeModule *module);
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
-	LOG ("Registering EphyPageInfoExtension")
+	LOG ("Registering EphyPageInfoExtension");
 
 #ifdef ENABLE_NLS
 	/* Initialize the i18n stuff */
